package config

import (
	"errors"
	"flag"

	"git.paulbsd.com/paulbsd/fuelprices/src/utils"
	"gopkg.in/ini.v1"
)

// GetConfig fetch config from ini file
func (c *Config) GetConfig() (err error) {
	flag.Usage = utils.Usage

	flag.StringVar(&c.ConfigPath, "configfile", "common.ini", "config file to use with fuelprices section")
	flag.Parse()

	config, err := ini.Load(c.ConfigPath)
	if err != nil {
		return
	}

	fuelpricesSection := config.Section("fuelprices")
	c.RemoteURL = fuelpricesSection.Key("remote_url").MustString("https://donnees.roulez-eco.fr/opendata/instantane")
	c.RemoteFilename = fuelpricesSection.Key("remote_filename").MustString("PrixCarburants_instantane.xml")
	c.XPathBase = fuelpricesSection.Key("xpath_base").MustString(".//pdv[@id='%s']/prix[@nom='%s']")
	c.Table = fuelpricesSection.Key("table").MustString("fuel_price")
	c.Pos = fuelpricesSection.Key("pos").Strings(",")
	if len(c.Pos) < 1 {
		err = errors.New("No pos defined")
		return
	}
	c.Types = fuelpricesSection.Key("types").Strings(",")
	if len(c.Types) < 1 {
		err = errors.New("No fuel types defined")
		return
	}

	influxdbSection := config.Section("influxdb")
	c.InfluxURL = influxdbSection.Key("url").MustString("http://localhost:8086")
	c.InfluxUser = influxdbSection.Key("username").MustString("username")
	c.InfluxPass = influxdbSection.Key("password").MustString("password")
	c.InfluxDB = influxdbSection.Key("database").MustString("me")

	if err != nil {
		return
	}

	return nil
}

// Config is the main configuration
type Config struct {
	ConfigPath     string
	RemoteURL      string
	RemoteFilename string
	XPathBase      string
	Pos            []string
	Types          []string
	Table          string
	InfluxURL      string
	InfluxUser     string
	InfluxPass     string
	InfluxDB       string
}
