package zipfile

import (
	"archive/zip"
	"bytes"
	"io/ioutil"
	"log"
	"net/http"
	"time"

	"git.paulbsd.com/paulbsd/fuelprices/src/config"
	"git.paulbsd.com/paulbsd/fuelprices/src/xmlfile"
)

// DownloadFile fetch file from webserver
func (zipfile *ZipFile) DownloadFile(c *config.Config) (err error) {
	pollTo := 30 * time.Millisecond

	client := &http.Client{Timeout: pollTo * time.Second, Transport: &http.Transport{
		IdleConnTimeout:    pollTo,
		DisableCompression: false,
	}}

	resp, err := client.Get(c.RemoteURL)
	if err != nil {
		return
	}
	defer resp.Body.Close()

	zipfile.Content, err = ioutil.ReadAll(resp.Body)
	if err != nil {
		return
	}

	time.Sleep(pollTo)

	return nil
}

// ExtractZip get the XML file to be processed
func (zipfile *ZipFile) ExtractZip(c *config.Config, xmlfile *xmlfile.XMLFile) (err error) {
	unzipped, err := zip.NewReader(bytes.NewReader(zipfile.Content), int64(len(zipfile.Content)))
	if err != nil {
		return
	}

	for _, file := range unzipped.File {
		if file.Name == c.RemoteFilename {
			rc, err := file.Open()
			if err != nil {
				return err
			}
			xmlfile.Content, err = ioutil.ReadAll(rc)
			rc.Close()
		} else {
			log.Fatal("File not found")
		}
	}
	return
}

// ZipFile source zipped file
type ZipFile struct {
	Filename string
	Filepath string
	Content  []byte
}
